@@ -241,7 +241,7 @@ parse_xml (GDataParsable *parsable, xmlDoc *doc, xmlNode *node, gpointer user_da
 	} else if (xmlStrcmp (node->name, (xmlChar*) "maxPhotosPerAlbum") == 0) {
 		/* gphoto:max-photos-per-album */
 		xmlChar *max_photos_per_album = xmlNodeListGetString (doc, node->children, TRUE);
-		self->priv->max_photos_per_album = strtol ((char*) max_photos_per_album, NULL, 10);
+		self->priv->max_photos_per_album = g_ascii_strtoll ((char*) max_photos_per_album, NULL, 10);
 		xmlFree (max_photos_per_album);
 	} else if (xmlStrcmp (node->name, (xmlChar*) "x-allowDownloads") == 0) { /* RHSTODO: see if this comes with the user */
 		/* gphoto:allowDownloads */
