@@ -54,11 +54,6 @@ struct _GDataTasksQueryPrivate {
 	gboolean show_completed;
 	gboolean show_deleted;
 	gboolean show_hidden;
-
-	/* These params are here not in GDataQuery due of differently named query params for JSON protocols therefore need for different parse_uri */
-	gint max_results;
-	gchar *page_token;
-	gint64 updated_min;
 };
 
 enum {
@@ -69,9 +64,6 @@ enum {
 	PROP_SHOW_COMPLETED,
 	PROP_SHOW_DELETED,
 	PROP_SHOW_HIDDEN,
-	PROP_MAX_RESULTS,
-	PROP_PAGE_TOKEN,
-	PROP_UPDATED_MIN,
 };
 
 G_DEFINE_TYPE (GDataTasksQuery, gdata_tasks_query, GDATA_TYPE_QUERY)
@@ -363,7 +355,7 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
  * gdata_tasks_query_new:
  * @q: (allow-none): a query string, or %NULL
  *
- * Creates a new #GDataTasksQuery with its #GDataQuery:q property set to @q.
+ * Creates a new #GDataTasksQuery. @q is unused and must be set to %NULL.
  *
  * Return value: a new #GDataTasksQuery
  *
@@ -372,7 +364,9 @@ get_query_uri (GDataQuery *self, const gchar *feed_uri, GString *query_uri, gboo
 GDataTasksQuery *
 gdata_tasks_query_new (const gchar *q)
 {
-	return g_object_new (GDATA_TYPE_TASKS_QUERY, "q", q, NULL);
+	/* Ignore the q parameter, as it's not used in any of the queries and
+	 * will cause errors. */
+	return g_object_new (GDATA_TYPE_TASKS_QUERY, NULL);
 }
 
 /**
@@ -412,6 +406,9 @@ gdata_tasks_query_set_completed_max (GDataTasksQuery *self, gint64 completed_max
 
 	self->priv->completed_max = completed_max;
 	g_object_notify (G_OBJECT (self), "completed-max");
+
+	/* Our current ETag will no longer be relevant. */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -451,6 +448,9 @@ gdata_tasks_query_set_completed_min (GDataTasksQuery *self, gint64 completed_min
 
 	self->priv->completed_min = completed_min;
 	g_object_notify (G_OBJECT (self), "completed-min");
+
+	/* Our current ETag will no longer be relevant. */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -490,6 +490,9 @@ gdata_tasks_query_set_due_max (GDataTasksQuery *self, gint64 due_max)
 
 	self->priv->due_max = due_max;
 	g_object_notify (G_OBJECT (self), "due-max");
+
+	/* Our current ETag will no longer be relevant. */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 
@@ -530,6 +533,9 @@ gdata_tasks_query_set_due_min (GDataTasksQuery *self, gint64 due_min)
 
 	self->priv->due_min = due_min;
 	g_object_notify (G_OBJECT (self), "due-min");
+
+	/* Our current ETag will no longer be relevant. */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -565,6 +571,9 @@ gdata_tasks_query_set_show_completed (GDataTasksQuery *self, gboolean show_compl
 
 	self->priv->show_completed = show_completed;
 	g_object_notify (G_OBJECT (self), "show-completed");
+
+	/* Our current ETag will no longer be relevant. */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -600,6 +609,9 @@ gdata_tasks_query_set_show_deleted (GDataTasksQuery *self, gboolean show_deleted
 
 	self->priv->show_deleted = show_deleted;
 	g_object_notify (G_OBJECT (self), "show-deleted");
+
+	/* Our current ETag will no longer be relevant. */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
 
 /**
@@ -635,4 +647,7 @@ gdata_tasks_query_set_show_hidden (GDataTasksQuery *self, gboolean show_hidden)
 
 	self->priv->show_hidden = show_hidden;
 	g_object_notify (G_OBJECT (self), "show-hidden");
+
+	/* Our current ETag will no longer be relevant. */
+	gdata_query_set_etag (GDATA_QUERY (self), NULL);
 }
