@@ -25,6 +25,9 @@
  *
  * #GDataTasksTask is a subclass of #GDataEntry to represent a task in a tasklist from Google Tasks.
  *
+ * All functionality of Tasks is currently supported except
+ * <ulink type="http" url="https://developers.google.com/google-apps/tasks/v1/reference/tasks#links">links</ulink>.
+ *
  * For more details of Google Tasks API, see the <ulink type="http" url="https://developers.google.com/google-apps/tasks/v1/reference/">
  * online documentation</ulink>.
  *
@@ -79,6 +82,7 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 {
 	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 	GDataParsableClass *parsable_class = GDATA_PARSABLE_CLASS (klass);
+	GDataEntryClass *entry_class = GDATA_ENTRY_CLASS (klass);
 
 	g_type_class_add_private (klass, sizeof (GDataTasksTaskPrivate));
 
@@ -90,6 +94,8 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 	parsable_class->get_json = get_json;
 	parsable_class->get_content_type = get_content_type;
 
+	entry_class->kind_term = "tasks#task";
+
 	/**
 	 * GDataTasksTask:parent:
 	 *
@@ -113,7 +119,7 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 	 *
 	 * Since: 0.15.0
 	 */
-	g_object_class_install_property (gobject_class, PROP_STATUS,
+	g_object_class_install_property (gobject_class, PROP_POSITION,
 	                                 g_param_spec_string ("position",
 	                                 "Position of task", "Position of the task among sibling tasks using lexicographical order.",
 	                                 NULL,
@@ -135,21 +141,25 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 	/**
 	 * GDataTasksTask:status:
 	 *
-	 * Status of the task. This is either "needsAction" or "completed".
+	 * Status of the task. This is either %GDATA_TASKS_STATUS_NEEDS_ACTION
+	 * or %GDATA_TASKS_STATUS_COMPLETED.
 	 *
 	 * Since: 0.15.0
 	 */
 	g_object_class_install_property (gobject_class, PROP_STATUS,
 	                                 g_param_spec_string ("status",
-	                                 "Status of task", "Status of the task. This is either \"needsAction\" or \"completed\".",
+	                                 "Status of task", "Status of the task.",
 	                                 NULL,
 	                                 G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/**
 	 * GDataTasksTask:due:
 	 *
-	 * Due date of the task (as a RFC 3339 timestamp).
-	 * This field is <code class="literal">-1</code> if task has not due date asigned.
+	 * Due date of the task (as a RFC 3339 timestamp; seconds since the UNIX
+	 * epoch).
+	 *
+	 * This field is <code class="literal">-1</code> if the task has no due
+	 * date assigned.
 	 *
 	 * Since: 0.15.0
 	 */
@@ -162,8 +172,11 @@ gdata_tasks_task_class_init (GDataTasksTaskClass *klass)
 	/**
 	 * GDataTasksTask:completed:
 	 *
-	 * Completion date of the task (as a RFC 3339 timestamp).
-	 * This field is <code class="literal">-1</code> if the task has not been completed.
+	 * Completion date of the task (as a RFC 3339 timestamp; seconds since
+	 * the UNIX epoch).
+	 *
+	 * This field is <code class="literal">-1</code> if the task has not
+	 * been completed.
 	 *
 	 * Since: 0.15.0
 	 */
@@ -345,25 +358,23 @@ get_json (GDataParsable *parsable, JsonBuilder *builder)
 		json_builder_add_string_value (builder, priv->status);
 	}
 	if (priv->due != -1) {
-		due = gdata_parser_int64_to_json_iso8601 (priv->due);
+		due = gdata_parser_int64_to_iso8601 (priv->due);
 		json_builder_set_member_name (builder, "due");
 		json_builder_add_string_value (builder, due);
 		g_free (due);
 	}
 	if (priv->completed != -1) {
-		completed = gdata_parser_int64_to_json_iso8601 (priv->completed);
+		completed = gdata_parser_int64_to_iso8601 (priv->completed);
 		json_builder_set_member_name (builder, "completed");
 		json_builder_add_string_value (builder, completed);
 		g_free (completed);
 	}
 
-	if (priv->deleted == TRUE) {
-		json_builder_set_member_name (builder, "deleted");
-		json_builder_add_boolean_value (builder, TRUE);
-	} else {
-		json_builder_set_member_name (builder, "deleted");
-		json_builder_add_boolean_value (builder, FALSE);
-	}
+	json_builder_set_member_name (builder, "deleted");
+	json_builder_add_boolean_value (builder, priv->deleted);
+
+	json_builder_set_member_name (builder, "hidden");
+	json_builder_add_boolean_value (builder, priv->hidden);
 }
 
 static const gchar *
